@@ -11,44 +11,48 @@ pub fn parse_opts() -> App<'static, 'static> {
             .short("i")
             .long("input")
             .value_name("INDEX")
-            .help("Set temp file index to read from")
+            .help("Set tempfile INDEX to write into")
             .takes_value(true))
         .arg(Arg::with_name("output")
             .short("o")
             .long("output")
             .value_name("INDEX")
-            .help("Set temp file index to write to")
+            .help("Set tempfile INDEX to read from")
             .takes_value(true))
         .arg(Arg::with_name("remove")
             .short("r")
             .long("remove")
             .value_name("INDEX")
-            .help("Set temp file index to remove")
+            .help("Set tempfile INDEX to remove")
             .takes_value(true))
         .arg(Arg::with_name("pop")
             .short("p")
             .long("pop")
             .help("Remove from top of stack"))
+        .arg(Arg::with_name("shift")
+            .short("s")
+            .long("shift")
+            .help("Remove from bottom of stack"))
         .arg(Arg::with_name("FILE")
-            .help("Read input FILE into a new temp file. If stdin is present the tempfile created from stdin instead.")
+            .help("Read input FILE into a new tempfile. If stdin is present the tempfile is created from stdin instead.")
             .required(false)
             .index(1))
         .arg(Arg::with_name("list_files")
             .short("l")
             .long("list-files")
-            .help("List all temp files on the stack to stdout"))
+            .help("List all tempfiles on the stack to stdout"))
         .arg(Arg::with_name("list_contents")
             .short("L")
             .long("list-contents")
-            .help("List all temp files with contents on the stack to stdout"))
+            .help("List all tempfiles with contents on the stack to stdout"))
         .arg(Arg::with_name("silent")
-            .short("s")
-            .long("silent")
-            .help("No output when creating temp file"))
+            .short("q")
+            .long("quiet")
+            .help("No output when creating tempfile"))
         .arg(Arg::with_name("clear")
             .short("c")
             .long("clear")
-            .help("Remove all temp files"))
+            .help("Remove all tempfiles"))
         .arg(Arg::with_name("v")
             .short("v")
             .multiple(true)
